#
# spec file for package smc-tools
#
# Copyright (c) 2018-2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           smc-tools
Version:        1.5.0
Release:        bp153.1.7
Summary:        Shared Memory Communication via RDMA
License:        EPL-1.0
Group:          System/Kernel
URL:            https://www.ibm.com/developerworks/linux/linux390/smc-tools.html
Source:         %{name}-%{version}.tar.gz
Source1:        smc-tools-rpmlintrc
Patch1:         smc-tools-sles15sp3-smc_chk-Remove-EXPERIMENTAL-flag-for-C-option.patch
Patch2:         smc-tools-sles15sp3-Makefile-Install-smc_chk.8-on-s390-only.patch

BuildRequires:  bash-completion-devel
BuildRequires:  libnl3-devel
PreReq:         permissions

%description
Shared Memory Communication via RDMA (SMC) is a socket over RDMA
communication protocol that allows existing TCP socket applications to
transparently benefit from RDMA when exchanging data via an RDMA over
Converged Ethernet (RoCE) network.

The tools provided in this package allow existing TCP applications
to use a RoCE network without needing to make changes in them.

%package completion
Summary:        Bash completion for smc-tools
Group:          System/Kernel

Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description completion
This package contains the files to enable command completion for the
smc-tools package when running a bash shell.

%prep
%autosetup -p1

%build
# The next two lines are to get around the Makefile not adding
# its own values to CFLAGS if it is already set. This is needed
# so that we can specify the optflags macro to pull in our own
# parameters.
MYCFLAGS=$(grep ^CFLAGS Makefile | head -n1 | cut -f2 -d=)
MYCFLAGS+=" $(pkg-config --silence-errors --cflags libnl-genl-3.0)"
%make_build CFLAGS="${MYCFLAGS} %{optflags}"

%install
%make_install V=1

%ifarch s390 %{ix86}
rm -Rf "%{buildroot}%{_prefix}/lib64"
%endif

%verifyscript
%verify_permissions -e %{_prefix}/lib/libsmc-preload.so
%verify_permissions -e %{_libdir}/libsmc-preload.so

%post
%set_permissions %{_prefix}/lib/libsmc-preload.so
%set_permissions %{_libdir}/libsmc-preload.so

%files
%license LICENSE
%doc README.md
%{_bindir}/smc_dbg
%{_bindir}/smc_pnet
%{_bindir}/smc_run
%{_bindir}/smcd
%{_bindir}/smcr
%ifarch s390 s390x
%{_bindir}/smc_chk
%{_bindir}/smc_rnics
%endif
%{_bindir}/smcss
%{_libdir}/libsmc-preload.so
%{_mandir}/man7/af_smc.7%{?ext_man}
%{_mandir}/man8/smc_pnet.8%{?ext_man}
%ifarch s390 s390x
%{_mandir}/man8/smc_rnics.8%{?ext_man}
%{_mandir}/man8/smc_chk.8%{?ext_man}
%endif
%{_mandir}/man8/smc_run.8%{?ext_man}
%{_mandir}/man8/smcd-device.8%{?ext_man}
%{_mandir}/man8/smcd-info.8%{?ext_man}
%{_mandir}/man8/smcd-linkgroup.8%{?ext_man}
%{_mandir}/man8/smcd.8%{?ext_man}
%{_mandir}/man8/smcr-device.8%{?ext_man}
%{_mandir}/man8/smcr-info.8%{?ext_man}
%{_mandir}/man8/smcr-linkgroup.8%{?ext_man}
%{_mandir}/man8/smcr.8%{?ext_man}
%{_mandir}/man8/smcss.8%{?ext_man}

%files completion
%{_datadir}/bash-completion/completions/smc*

%changelog
* Wed Feb 10 2021 Mark Post <mpost@suse.com>
- Upgrade to version 1.5.0 (bsc#1181649).
  * Changes:
  - `smcd`/`smcr`: Add new command `info`
  - `smc_rnics`: Use '`n/a`' to indicate missing PNET ID
  - `smc_chk`: New tool to perform SMC eligilibilty checks,
    requires `man` and `python3` to be installed
  - `man` pages: Consistency improvements
  * Bug fixes:
  - `smc_pnet.8`: Use correct spelling for 'PNET ID'
  - `smc_rnics`: Suppress output of port attribute for offline devices
- Added smc-tools-sles15sp3-Makefile-Install-smc_chk.8-on-s390-only.patch
  The smc_chk command is only built for s390/s390x systems. Don't include the
  man page for it on systems where the command doesn't exist.
- Added smc-tools-sles15sp3-smc_chk-Remove-EXPERIMENTAL-flag-for-C-option.patch
  The 'EXPERIMENTAL' portion could be irritating to users of option '-C' -
  this functionality is ready for prime time. However, the same code is
  also called by one of the undocumented _experimental_ features, and
  it makes sense in that context.
* Wed Jan 27 2021 Mark Post <mpost@suse.com>
- Added a BuildRequires for bash-completion-devel so that the
  completion file for smc will be built and installed. (bsc#1181360)
- Created a new sub-package, smc-tools-completion, to deliver the
  bash completion files.
- Replaced the "make" command with the %%make_build macro according
  to the recommendation from spec-cleaner.
* Mon Dec  7 2020 Mark Post <mpost@suse.com>
- Upgraded to version 1.4.0 (bsc#1179554, jsc#SLE-13707)
  * Changes:
  - Add SMC-Dv2 support
  - `smc`: Add new tools `smcd` and `smcr` to list linkgroups, links and
    devices. Requires Linux kernel 5.11 or higher.
  - `smc_rnics`: Display enabled devices per default, add new option `--all`
  - `smc_rnics`: Sort output by FID
  * Bug fixes:
  - `smc_rnics`/`smc_dbg`: Fix PNETID for multiport devices
  - `smcss`/`smc_pnet`: Consistent use of option `-v`
- Changed the %%setup macro to %%autosetup in the spec file.
* Wed Sep 16 2020 Mark Post <mpost@suse.com>
- Upgraded to version 1.3.1 (jsc#SLE-13707)
  * Version 1.3.1
    Changes:
    smcss: Add further error codes to man page
    Bug fixes:
    smcss: Display more than 321 connections
    smc_rnics: Suppress any unknown non-networking device unless
    option -r is specified
  * Version 1.3.0
    Changes:
    smcss: Add description of Linux error codes to man page
    smc_rnics:
  * Sort output by PCHID
  * Replace spaces in output by underscores for easier parsing
  * Add new option --IB-dev to display IB-specific attributes
    Bug fixes:
    smc_rnics:
  * FIDs can have up to 4 digits and are planned to be extended
    to a total of 8 digits - adjusting output format accordingly
  * Do not display port attribute for RoCE Express2 devices
    unless we have an accurate value
* Thu Nov  7 2019 Mark Post <mpost@suse.com>
- Upgraded to version 1.2.2 (jsc#SLE-7876)
  * Changes:
    Add bash autocompletion support
    Removed support for the 31-bit library
    Bug fixes:
    smcss: Do not show connection mode for already closed sockets
    smc_rnics: Set interface to "n/a" for ISM devices
* Tue Sep  3 2019 Mark Post <mpost@suse.com>
- Upgraded to version 1.2.1 (Fate#327839, bsc#1153947)
  * Version 1.2.1
    Bug fixes:
    smc_rnics: Install man page on s390 only
    smc-preload: Handle behavior flags in type argument to socket() call
    Makefile: Fixed install target on Ubuntu for platforms other than s390
    smc_pnet: changes in support of kernel 5.1
  * Version 1.2.0
    Changes:
    smc_rnics: Initial version added
    smc_dbg: Initial version added
    Bug fixes:
    smcss: Parse address family of ip address
* Fri Nov 30 2018 mpost@suse.com
- Made multiple changes to the spec file based on the output
  from spec-cleaner.
* Fri Jul 27 2018 mpost@suse.com
- Upgraded to version 1.1.0 (Fates 325009, 325168 and 325702)
  Changes:
  * smcss:    Add IPv6 support
  * preload:  Add IPv6 support
  * smcss:    Output format changed
  * preload:  Rename preload library into libsmc-preload.so
  * Makefile: Improve distro compatibility
  * Makefile: Add SONAME to shared libraries
  * Makefile: Do not strip binaries on install
  * Makefile: Use LDFLAGS to allow addition of externally set link flags
  * libsmc..: Remove hardcoded reference to libc
  * Manpages: Formatting changes
  Bug fixes:
  * Makefile: Fix target 'install' dependencies
  * smcss:    Fix "--version" output
  * smc_pnet: Fix "--version" output
  * smc_run:	Append preload library to LD_PRELOAD instead of potentially
    overwriting pre-set values
  * preload:  Set suid flag to work with suid executables
- Updated the spec file to reference the new names for the shared
  library.
- Removed the ExcludeArch for %%{arm} since it now builds on that
  architecture.
* Fri Sep 29 2017 mpost@suse.com
- Added an ExcludeArch for %%{arm} so that we won't try to build
  the package on armv7l. The build fails on that architecture.
* Mon Apr  3 2017 jengelh@inai.de
- Update summary. Replace old RPM shell variables by macros.
* Mon Mar 20 2017 mpost@suse.com
- Upgraded to version 1.0.0 (Fate#322376).
* Fri May  6 2016 mpost@suse.com
- Initial packaging of version 0.1.1 (Fate#319569).
